@@ -204,17 +204,6 @@ def model_update(
             action_dict["parameters"] = include_includes(
                 action_dict["parameters"], branch, model_fn
             )
-        try:
-            image, tag = doc["location"]["image"].split(":")
-        except ValueError:
-            image = doc["location"]["image"]
-        if nomitall == "nomitall-prod":
-            tag = "prod"
-        elif nomitall == "nomitall-stage":
-            tag = "stage"
-        else:
-            tag = "stage"
-        doc["location"]["image"] = ":".join([image, tag])
     else:
         doc["parameters"] = include_includes(doc["parameters"], branch, model_fn)
 
